{% extends "base.html" %}
{% block title %}Home{% endblock %}
{% block content %}
    <div>
        {% for post in posts %}
        <div class="posts">
            <section class="post">
                <header class="post-header">
                    <h1 class="post-title">
                        <a href="{{ post.metadata['title'] }}.html">{{ post.metadata['title'] }}</a>
                    </h1>
                </header>
                <p>
                    {{ post.metadata['description'] }}
                </p>
            </section>
        </div>
        {% endfor %}
    </div>
{% endblock %}